package com.ruoyi.web.modules.circulation.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Param;
import com.ruoyi.web.modules.circulation.domain.BizTradeMarket;

/**
 * 交易市场 Mapper
 */
public interface BizTradeMarketMapper
{
    BizTradeMarket selectBizTradeMarketById(Long id);

    BizTradeMarket selectBizTradeMarketByIdAny(Long id);

    int countBizTradeMarketByNameExcludeId(@Param("marketName") String marketName,
            @Param("excludeId") Long excludeId);

    List<BizTradeMarket> selectBizTradeMarketList(BizTradeMarket query);

    int insertBizTradeMarket(BizTradeMarket row);

    int updateBizTradeMarket(BizTradeMarket row);

    int logicDeleteBizTradeMarketByIds(@Param("ids") Long[] ids, @Param("updateBy") String updateBy);
}
